function [] = Lite_Example1()

clc;
clear;

% Read mesh
load backwardFacingStepGeometry2D.mat;

% Convert mesh to second order
[p,e,t,nVnodes,nPnodes,indices] = convertMeshToSecondOrder(p,e,t);

% Define fluid
nu = 0.02;

% Initialize solution and set convergence criteria
[u, convergence] = initSolution(p,t,[0.5 0],0);
maxres = 1e-5;
maxiter = 25;

% Define inlet velocity profile
vel = @(x,y)([4*(y)*(1-y) 0]);

% Iterate nonlinear terms
for iter = 1:maxiter
    % Assemble matrix and right hand side
    [NS, F] = assembleNavierStokesMatrix2D(p,e,t,nu,u(indices.indu),u(indices.indv),'nosupg');
    
    % Apply boundary conditions
    [NS, F] = imposeCfdBoundaryCondition2D(p,e,t,NS,F,[1 3 5 6 7],'wall');
    [NS, F] = imposeCfdBoundaryCondition2D(p,e,t,NS,F,2,'inlet', vel);
    
    % Solve equations
    u = NS\F;
end


    
    figure(1)
displaySolution2D(p,t,u(indices.indu),'x-velocity');
xlim([-1 7])
ylim([-3 3])

% Plot solution


% Export results
exportToGmsh2D('example1_result.msh',u(indices.indu),p,t,'x-velocity');

% Visit also www.quickersim.com/cfd-toolbox-for-matlab/index and subscribe.
% You will get access to documentation, code examples, video and pdf
% tutorials. You can also ask for simple help at support@quickersim.com or
% buy dedicated, professional support service for your business.
% Check out also a list of currently on-going workshops and trainings with
% many additional examples, documentation and heat transfer applications.
% We also develop customized apps and offer on-site training for your team.

disp('Congratulations! You can view the source code by typing:');
disp('edit Lite_Example1');
disp('or go directly to www.quickersim.com/cfd-toolbox-for-matlab/index');
disp('to download your first geometry creation, meshing, solving and');
disp('postprocessing tutorial and some additonal source code examples');
disp('that will teach you using this QuickerSim CFD Toolbox.');

end