clear all
close all

%This code relies heavily on the QuickerSim CDF Toolbox. I realize that
%this limits the amount of participation I actually had in designing the
%simulation, though I only resorted to this toolbox after failing to
%successfully model the NS equation. If required, I will provide those
%failed efforts as well. 

%While it is possible to generate the initial construct in Matlab, the 
%Gmsh program is used to generate the  structure as a mesh. This
%was the result of a recommendation by Daniel L., a College of Chemistry 
%graduate student, and is read in via fscanf. 



%Import file from Gmsh and allow for additional complexity.
[p,e,t] = importMeshGmsh('cylinder.msh');
[p,e,t,nVnodes,nPnodes,indices] = convertMeshToSecondOrder(p,e,t);
f= 0;

% Fluid viscocity.
nu = 0.01;

% Initial temporal and velocity conditions.
[u] = initSolution(p,t,[1 0],0);
maxres = 1e-5;
maxrevs = 100;

% Iterative loop.
for iter = 1:maxrevs
    [NS, F] = assembleNavierStokesMatrix2D(p,e,t,nu,u(indices.indu),u(indices.indv),'nosupg');
    
    % Solve Navier-Stokes at boundaries, denoted by objects in mesh (10 is
    % left boundary, 12 are channel boundaries, 13 is obstacle).
    [NS, F] = imposeCfdBoundaryCondition2D(p,e,t,NS,F,10,'inlet', [1 0]);
    [NS, F] = imposeCfdBoundaryCondition2D(p,e,t,NS,F,12,'slipAlongX');
    [NS, F] = imposeCfdBoundaryCondition2D(p,e,t,NS,F,12,'slipAlongY');
    [NS, F] = imposeCfdBoundaryCondition2D(p,e,t,NS,F,13,'wall');
    
   
    
    % Correct Navier-Stokes for external forces, reset velocity for next
    % iteration.
    u = NS\F;
    
    % Generate pressure data
    pressure = generatePressureData(u,p,t);

    % Display velocity field and allow for imaging.

    if iter < 30
      f=f+1;
    end
    displaySolution2D(iter,f,p,t,u(indices.indu),'x-velocity field [m/s]')
    
    %The displaySolution2D function must be altered to allow for imaging as
    %well, by the addition of the iter and f variables as inputs. The
    %following is then added within the display loop: 
    %if iter < 30
    %  f = f+1;
    %  saveas(gcf, ['image_',sprintf('%03d',f),'.png'])
    %end
    

end

% Overlay pressure on original mesh via Gmsh geometric construction tool. 
%exportToGmsh2D('pressure.msh',pressure,p,t,'pressure field');


