function [] = displaySolution2D(iter,f,p,t, field, label)

% displaySolution2D - Display scalar field in 2D.
%
% This QuickerSim CFD Toolbox function displays a 2-D scalar field.
%
% displaySolution2D(p, t, field, label)
%
% Input arguments:
% p - array of nodal coordinates (see help of the importMeshGmsh function
%     for details).
% t - array of finite elements (see help of the importMeshGmsh function for
%     details).
% field - column vector of nnodes elements storing field values at
%     corresponding mesh nodes.
% label - a string which is displayed as the title over the color map.
%
% Visit also www.quickersim.com/cfd-toolbox-for-matlab/index and subscribe.
% You will get access to documentation, code examples, video and pdf
% tutorials. You can also ask for simple help at support@quickersim.com or
% buy dedicated, professional support service for your business.
% Check out also a list of currently on-going workshops and trainings with
% many additional examples, documentation and heat transfer applications.
% We also develop customized apps and offer on-site training for your team.
%
% See also: DISPLAYMESH2D, IMPORTMESHGMSH.

nPnodes = max(max(t(1:3,:)));

trisurf(t(1:3,:)',p(1,1:nPnodes)',p(2,1:nPnodes)',zeros(nPnodes,1),field(1:nPnodes))
shading('interp')
colormap('jet')
colorbar
axis equal
view([0 90])
title(label)
xlabel('x')
ylabel('y')

%Image loop for movie.
% if iter < 30
%     f = f+1;
%     saveas(gcf, ['image_',sprintf('%03d',f),'.png'])
%end

end