function [] = plotResiduals(convergence, figureId)

% plotResiduals - Display convergence plot and print residuals to console.
%
% This QuickerSim CFD Toolbox function, if called in each iteration of the
% solver run, displays actual convergence of the velocity residuals in a
% chosen Matlab window and prints iteration number and current residuals to
% console window.
%
% plotResiduals(convergence, figureId)
%
% Input arguments:
% convergence - array initialized with initSolution function and filled in
%               at least once with the computeResiduals function.
% figureId    - id of the Matlab window in which to display the plot. If
%               the window does not exist at the moment, it will be
%               created. If it does exist, data will be added to the
%               previous convergence plot.
%
% Visit also www.quickersim.com/cfd-toolbox-for-matlab/index and subscribe.
% You will get access to documentation, code examples, video and pdf
% tutorials. You can also ask for simple help at support@quickersim.com or
% buy dedicated, professional support service for your business.
% Check out also a list of currently on-going workshops and trainings with
% many additional examples, documentation and heat transfer applications.
% We also develop customized apps and offer on-site training for your team.
%
% See also: COMPUTERESIDUALS, INITSOLUTION.

figure(figureId)
semilogy(convergence(:,1),convergence(:,2:3))
title('Residuals convergence plot');
xlabel('Iteration')
ylabel('Residual value [-]');
legend('x-velocity residual','y-velocity residual');
grid on;
drawnow;

disp(convergence(end,:));

end